ngff_zarr.methods._support - ngff-zarr
Description: Module Contents: Functions:,,_dim_scale_factors,,,_align_chunks,,,_compute_sigma, Compute Gaussian kernel sigma values in pixel units for downsampling. sigma = sqrt((k^2 - 1^2)/(2 sqrt(2 ln(2)))^2)...

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.methods._support`

## Module Contents

### Functions

`_dim_scale_factors` |
`_align_chunks` |
`_compute_sigma` | Compute Gaussian kernel sigma values in pixel units for downsampling. sigma = sqrt((k^2 - 1^2)/(2sqrt(2ln(2)))^2) Ref https://discourse.itk.org/t/resampling-to-isotropic-signal-processing-theory/1403/16 https://doi.org/10.1007/978-3-319-24571-3_81 http://discovery.ucl.ac.uk/1469251/1/scale-factor-point-5.pdf
`_get_block` | Helper method for accessing an enumerated chunk from input

### Data

`_spatial_dims` |

### API

ngff_zarr.methods._support._spatial_dims

  None

ngff_zarr.methods._support._dim_scale_factors(dims, scale_factor, previous_dim_factors)

ngff_zarr.methods._support._align_chunks(previous_image, default_chunks, dim_factors)

ngff_zarr.methods._support._compute_sigma(shrink_factors: List[int]) → List[float]

  Compute Gaussian kernel sigma values in pixel units for downsampling. sigma = sqrt((k^2 - 1^2)/(2sqrt(2ln(2)))^2) Ref https://discourse.itk.org/t/resampling-to-isotropic-signal-processing-theory/1403/16 https://doi.org/10.1007/978-3-319-24571-3_81 http://discovery.ucl.ac.uk/1469251/1/scale-factor-point-5.pdf

  Note: If input spacing / output sigma in physical units, the function would be sigma = sqrt((input_spacing^2*(k^2 - 1^2))/(2sqrt(2ln(2)))^2)

  input spacings: List Input image physical spacings in xyzt order

  shrink_factors: List Shrink ratio along each axis in xyzt order

  result: List Standard deviation of Gaussian kernel along each axis in xyzt order

ngff_zarr.methods._support._get_block(previous_image: ngff_zarr.ngff_image.NgffImage, block_index: int)

  Helper method for accessing an enumerated chunk from input